Re-exports
pub use ogg_vorbis::OggVorbisReader;
Modules
Structs
Functions
- Read a sample of data at the given start time and for the target duration from a file. This uses a table file if available and otherwise fallsback to a linear scan.
pub use ogg_vorbis::OggVorbisReader;